pepys\_import.core package
==========================

Subpackages
-----------

.. toctree::

   pepys_import.core.formats
   pepys_import.core.store

Module contents
---------------

.. automodule:: pepys_import.core
   :members:
   :undoc-members:
   :show-inheritance:
